@@ -284,88 +284,195 @@ def parse_args(argv):
     parser.add_argument(
         '-a', '--architecture',
         dest='architecture',
+        metavar='ARCH',
         choices=['x86', 'arm', 'thumb', 'mips', 'pic32', 'powerpc'],
-        help='architecture to force when (de)compiling'
+        help='Architecture to force when (de)compiling. Choices: %(choices)s.'
     )
     parser.add_argument(
         '-b', '--brief',
         dest='brief',
         action='store_true',
-        help='print fewer information during the decompilation'
+        help='Print fewer information during the decompilation.'
     )
     parser.add_argument(
         '-c', '--compiler',
         dest='comp_compiler',
+        metavar='COMPILER',
         choices=['gcc', 'clang'],
-        help='compiler to be used when compiling'
+        help='Compiler to be used when compiling. '
+             'Choices: %(choices)s. Default: gcc.'
     )
     parser.add_argument(
         '-C', '--compiler-optimizations',
         dest='comp_optimizations',
+        metavar='LEVEL',
         choices=['O0', 'O1', 'O2', 'O3'],
-        help='compiler optimizations to be used when compiling'
+        help='Compiler optimizations to be used when compiling. '
+             'Choices: %(choices)s. Default: O2.'
     )
     parser.add_argument(
         '-g', '--compiler-debug',
         dest='comp_debug',
         action='store_true',
         default=None,
-        help='compile the input C file with debugging information'
+        help='Compile the input C file with debugging information.'
     )
     parser.add_argument(
         '-s', '--compiler-strip',
         dest='comp_strip',
         action='store_true',
         default=None,
-        help='strip the compiled C file prior its decompilation'
+        help='Strip the compiled C file prior its decompilation.'
     )
     parser.add_argument(
         '-f', '--file-format',
         dest='file_format',
+        metavar='FORMAT',
         choices=['elf', 'pe'],
-        help='file format to force when compiling'
+        help='File format to force when compiling C source code or when '
+             'decompiling raw machine code. Choices: %(choices)s. Default: elf.'
     )
     parser.add_argument(
         '-l', '--target-language',
         dest='target_language',
+        metavar='LANGUAGE',
         choices=['c', 'py'],
-        help='target high-level language'
+        help='Target high-level language. '
+             'Choices: %(choices)s. Default: c.'
+    )
+    parser.add_argument(
+        '--graph-format',
+        dest='graph_format',
+        metavar='FORMAT',
+        choices=['png', 'svg', 'pdf'],
+        help='Format of the generated call and control-flow graphs.'
+             'Choices: %(choices)s. Default: png.'
     )
     parser.add_argument(
         '-m', '--mode',
         dest='mode',
-        choices=['c', 'bin'],
-        help='decompilation mode (default: automatic detection)'
+        metavar='MODE',
+        choices=['c', 'bin', 'raw'],
+        help='Decompilation mode. '
+             'Choices: %(choices)s. Default: automatic detection.'
     )
     parser.add_argument(
         '-o', '--output-dir',
         dest='output_dir',
         metavar='DIR',
-        help='save the outputs into this directory'
+        help='Save the outputs into this directory.'
     )
     parser.add_argument(
         '-p', '--pdb-file',
         dest='pdb_file',
         metavar='FILE',
-        help='PDB file associated with the input file'
+        help='PDB file associated with the input file.'
     )
     parser.add_argument(
         '-q', '--quiet',
         dest='quiet',
         action='store_true',
-        help='print only errors, nothing else (not even progress)'
+        help='Print only errors, nothing else (not even progress).'
+    )
+    parser.add_argument(
+        '--var-names',
+        dest='decomp_var_names',
+        metavar='STYLE',
+        choices=['readable', 'address', 'hungarian', 'simple', 'unified'],
+        help='Naming style for variables. '
+             'Choices: %(choices)s. Default: readable.'
+    )
+    parser.add_argument(
+        '-O', '--optimizations',
+        dest='decomp_optimizations',
+        metavar='LEVEL',
+        choices=['none', 'limited', 'normal', 'aggressive'],
+        help='Level of optimizations performed by the decompiler. '
+             'Choices: %(choices)s. Default: normal.'
+    )
+    parser.add_argument(
+        '-K', '--keep-unreach-funcs',
+        dest='decomp_unreach_funcs',
+        action='store_true',
+        default=None,
+        help='Decompile all functions, even if they are not reachable.'
+    )
+    parser.add_argument(
+        '--no-addresses',
+        dest='decomp_emit_addresses',
+        action='store_false',
+        default=None,
+        help='Disable the emission of addresses in comments in the generated code.'
+    )
+    parser.add_argument(
+        '--only-funcs',
+        dest='sel_decomp_funcs',
+        metavar='FUNCS',
+        help='Decompile only the given functions (a comma-separated '
+             'list of function names, e.g. func1,func2).'
+    )
+    parser.add_argument(
+        '--only-ranges',
+        dest='sel_decomp_ranges',
+        metavar='RANGES',
+        help='Decompile only the given address ranges (a comma-separated '
+             'list of address ranges, e.g. 0x100-0x200,0x500-0x600).'
+    )
+    parser.add_argument(
+        '--decoding',
+        dest='sel_decomp_decoding',
+        metavar='TYPE',
+        choices=['everything', 'only'],
+        help='What should be decoded in a selective decompilation? '
+             'Choices: %(choices)s. Default: everything.'
+    )
+    parser.add_argument(
+        '--raw-endian',
+        dest='raw_endian',
+        metavar='ENDIAN',
+        choices=['little', 'big'],
+        help='Endianness of the machine code (raw mode only). '
+             'Choices: %(choices)s. Default: little.'
+    )
+    parser.add_argument(
+        '--raw-entry-point',
+        dest='raw_entry_point',
+        metavar='ADDRESS',
+        help='Virtual memory address where execution flow should start '
+             'in the machine code (raw mode only).'
+    )
+    parser.add_argument(
+        '--raw-section-vma',
+        dest='raw_section_vma',
+        metavar='ADDRESS',
+        help='Address where the section created from the machine '
+             'code will be placed in virtual memory (raw mode only).'
+    )
+    parser.add_argument(
+        '--with-cg',
+        dest='generate_cg',
+        action='store_true',
+        default=None,
+        help='Generate a call graph.'
+    )
+    parser.add_argument(
+        '--with-cfgs',
+        dest='generate_cfgs',
+        action='store_true',
+        default=None,
+        help='Generate call graphs for all functions.'
     )
     parser.add_argument(
         '--with-archive',
         dest='generate_archive',
         action='store_true',
         default=None,
-        help='generate an archive containing all decompilation outputs'
+        help='Generate an archive containing all decompilation outputs.'
     )
     parser.add_argument(
         'input_file',
         metavar='FILE',
-        help='file to decompile'
+        help='File to decompile.'
     )
     return parser.parse_args(argv[1:])
 
@@ -437,12 +544,25 @@ def main(argv=None):
     add_decompilation_param_when_given(args, params, 'pdb_file')
     add_decompilation_param_when_given(args, params, 'mode')
     add_decompilation_param_when_given(args, params, 'target_language')
+    add_decompilation_param_when_given(args, params, 'graph_format')
     add_decompilation_param_when_given(args, params, 'architecture')
     add_decompilation_param_when_given(args, params, 'file_format')
     add_decompilation_param_when_given(args, params, 'comp_compiler')
     add_decompilation_param_when_given(args, params, 'comp_optimizations')
     add_decompilation_param_when_given(args, params, 'comp_debug')
     add_decompilation_param_when_given(args, params, 'comp_strip')
+    add_decompilation_param_when_given(args, params, 'decomp_var_names')
+    add_decompilation_param_when_given(args, params, 'decomp_optimizations')
+    add_decompilation_param_when_given(args, params, 'decomp_unreach_funcs')
+    add_decompilation_param_when_given(args, params, 'decomp_emit_addresses')
+    add_decompilation_param_when_given(args, params, 'sel_decomp_funcs')
+    add_decompilation_param_when_given(args, params, 'sel_decomp_ranges')
+    add_decompilation_param_when_given(args, params, 'sel_decomp_decoding')
+    add_decompilation_param_when_given(args, params, 'raw_endian')
+    add_decompilation_param_when_given(args, params, 'raw_entry_point')
+    add_decompilation_param_when_given(args, params, 'raw_section_vma')
+    add_decompilation_param_when_given(args, params, 'generate_cg')
+    add_decompilation_param_when_given(args, params, 'generate_cfgs')
     add_decompilation_param_when_given(args, params, 'generate_archive')
     decompilation = decompiler.start_decompilation(**params)
 
@@ -464,6 +584,17 @@ def main(argv=None):
         file_path = decompilation.save_binary(output_dir)
         display_download_progress(displayer, file_path)
 
+    if args.generate_cg:
+        decompilation.wait_until_cg_is_generated()
+        file_path = decompilation.save_cg(output_dir)
+        display_download_progress(displayer, file_path)
+
+    if args.generate_cfgs:
+        for func in decompilation.funcs_with_cfg:
+            decompilation.wait_until_cfg_is_generated(func)
+            file_path = decompilation.save_cfg(func, output_dir)
+            display_download_progress(displayer, file_path)
+
     if args.generate_archive:
         decompilation.wait_until_archive_is_generated()
         file_path = decompilation.save_archive(output_dir)
